summaryrefslogtreecommitdiffstats
path: root/kdat/LoggerWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/LoggerWidget.h')
-rw-r--r--kdat/LoggerWidget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/LoggerWidget.h b/kdat/LoggerWidget.h
index d649e65..1dd43e9 100644
--- a/kdat/LoggerWidget.h
+++ b/kdat/LoggerWidget.h
@@ -35,10 +35,10 @@ public:
* Create a titled logging widget
*
* @param title The title text displayed above the logging window.
* @param tqparent The tqparent widget.
* @param name The name of this widget.
*/
- LoggerWidget( const TQString & title, TQWidget* tqparent = 0, const char* name = 0 );
+ LoggerWidget( const TQString & title, TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the logging widget.
@@ -35,10 +35,10 @@ public:
*
* @param title The title text displayed above the logging window.
- * @param tqparent The tqparent widget.
+ * @param parent The parent widget.
* @param name The name of this widget.
*/